@@ -121,6 +121,10 @@ nma.krahn <- function(x, tau.preset=0){
   ##
   direct2 <- data.frame(direct2)
   
+  if (length(unique(studies$design)) == 1) {
+    warning("Only a single design in network meta-analysis.", call. = FALSE)
+    return(invisible(NULL))
+  }
   
   V.design <- diag(direct2$seTE.2arm^2,
                    nrow=length(direct2$seTE.2arm),
